/*
 * Common functionality.
 *
 * Copyright (C) 2022 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <l4/util/elf.h>

#include "common.h"



/* Find the L4Re auxiliary structure from program argument details. */

l4re_aux_t *exec_get_l4re_aux(int argc, char *argv[])
{
  /* Start after the final terminator (at argc) of the argument vector. */

  l4_umword_t *arg = ((l4_umword_t *) &argv[argc]) + 1;

  /* The environment vector is traversed. */

  while (*arg)
    arg++;

  /* Skip the terminating null entry. */

  arg++;

  /* Traverse the auxiliary vector. */

  struct auxv_entry *entry = (struct auxv_entry *) arg;

  for (; entry->key; entry++)
  {
    if (entry->key == AT_L4_AUX)
      return (l4re_aux_t *) entry->value;
  }

  return NULL;
}

/* vim: tabstop=2 expandtab shiftwidth=2
*/
